<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdFemCreateFromShape</name>
    <message>
      <location filename="../../Command.cpp" line="+50"/>
      <source>Fem</source>
      <translation>有限元</translation>
    </message>
    <message>
      <source>Create FEM mesh</source>
      <translation>创建有限元网格</translation>
    </message>
    <message>
      <source>Create FEM mesh from shape</source>
      <translation>从形体创建有限元网格</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+38"/>
      <source>FEM</source>
      <translation>有限元</translation>
    </message>
    <message>
      <source>&amp;FEM</source>
      <translation>有限元(&amp;F)</translation>
    </message>
  </context>
</TS>
